"use client";

import Image from "next/image";
import { useCallback } from "react";

import useEmblaCarousel from "embla-carousel-react";
import { motion } from "framer-motion";
import { ArrowDown, ChevronLeft, ChevronRight } from "lucide-react";

import { Button } from "@/components/ui/button";
import { Locale } from "@/i18n/routing";
import { cn } from "@/lib/utils";
import { AboutProductDetailsData } from "@/utils/get-fake-data";

interface AboutProductDetailsClientProps {
	data: AboutProductDetailsData;
	locale: Locale;
}

export function AboutProductDetailsClient({
	data,
	locale,
}: AboutProductDetailsClientProps) {
	const isRTL = locale === "ar";
	const [emblaRef, emblaApi] = useEmblaCarousel({
		direction: isRTL ? "rtl" : "ltr",
		loop: true,
		slidesToScroll: 1,
	});

	const scrollPrev = useCallback(() => {
		if (emblaApi) emblaApi.scrollPrev();
	}, [emblaApi]);

	const scrollNext = useCallback(() => {
		if (emblaApi) emblaApi.scrollNext();
	}, [emblaApi]);

	return (
		<section className="container mx-auto grid gap-8 px-4 py-16 lg:grid-cols-2">
			{/* Content */}
			<div className={cn("space-y-6", isRTL && "text-right")}>
				<h2
					className={cn(
						"text-4xl font-bold lg:text-5xl",
						isRTL && "font-arabic"
					)}
				>
					{data.title?.[locale]}
				</h2>
				<div className="rounded-xl border-2 border-[#2895C8] p-6">
					<p className={cn("text-lg text-gray-600", isRTL && "font-arabic")}>
						{data.description?.[locale]}
					</p>
				</div>
				<Button className="mt-6 rounded-xl bg-[#2895C8] px-6 py-4 text-white hover:bg-[#2895C8]/90">
					{data.discoverButtonText?.[locale]}
					<ArrowDown className="ml-2 h-6 w-6" />
				</Button>
			</div>

			{/* Carousel Section */}
			<div className="relative">
				{/* Gray Background Container */}
				<div className="relative h-[800px] rounded-lg bg-gray-600">
					{/* Carousel Container */}
					<div ref={emblaRef} className="h-full overflow-hidden">
						<div className="flex h-full">
							{Array.from({ length: Math.ceil(data.images.length / 2) })?.map(
								(_, groupIndex) => (
									<div
										key={groupIndex}
										className="relative min-w-full flex-shrink-0"
									>
										{/* Small Image - Positioned Absolutely */}
										<motion.div
											initial={{ opacity: 0, x: -50 }}
											animate={{ opacity: 1, x: 0 }}
											transition={{ duration: 0.6, ease: "easeOut" }}
										>
											<div className="relative h-[472.81px] w-[340.67px]">
												<Image
													src={"/about.png"}
													alt={data.images[groupIndex * 2].alt?.[locale]}
													fill
													className="absolute left-0 top-0 -rotate-45 rounded-lg object-cover"
												/>
											</div>
										</motion.div>
										<div>
											<Button className="h-16 w-16 rounded-full bg-[#2895C8] text-white hover:bg-[#2895C8]/90">
												{data.moreButtonText?.[locale]}
											</Button>
										</div>
										{/* Large Image - Positioned Absolutely */}
										<motion.div
											initial={{ opacity: 0, x: 50 }}
											animate={{ opacity: 1, x: 0 }}
											transition={{
												duration: 0.6,
												ease: "easeOut",
												delay: 0.2,
											}}
										// style={{
										//   position: "absolute",
										//   right: "2rem",
										//   top: "0%",
										//   transform: "translateY(-50%)",
										//   width: "463px",
										//   height: "619px",
										// }}
										>
											<div className="relative h-[619px] w-[463px]">
												<Image
													src={"/about.png"}
													alt={data.images[groupIndex * 2 + 1].alt?.[locale]}
													fill
													className="rounded-lg object-cover"
												/>
											</div>
										</motion.div>
									</div>
								)
							)}
						</div>
					</div>
				</div>

				{/* Navigation Buttons - Outside and below */}
				<div className="absolute bottom-[-4rem] right-0 flex gap-4">
					<Button
						variant="outline"
						size="icon"
						onClick={scrollPrev}
						className="rounded-full bg-[#2895C8] text-white hover:bg-[#2895C8]/90"
					>
						<ChevronLeft className="h-6 w-6" />
					</Button>
					<Button
						variant="outline"
						size="icon"
						onClick={scrollNext}
						className="rounded-full bg-[#2895C8] text-white hover:bg-[#2895C8]/90"
					>
						<ChevronRight className="h-6 w-6" />
					</Button>
				</div>
			</div>
		</section>
	);
}
